# -*- coding: utf-8 -*-
"""
    tqwgp-parser.cli
    ~~~~~~~~~~~~~~~~~~~~~
    CLI for the TQWGP parser, allowing to parse JSON, Yaml and Toml.

    This is a Work-in-Progress.

    :copyright: (c) 2021 Yoan Tournade.
"""
import os

# TODO Implement TQWGP text-base document parsing CLI.
# Allowing to take various input format:
# - Python;
# - JSON;
# - Yaml;
# - Toml.


def load_project(project, file, project_path=None):
    # TODO Allows to load project by path. By require
    # to extract the project name from the path.
    if os.path.isdir(project):
        pathProject = project
        project = project.split("/")[-2 if project[-1] == "/" else -1]
    elif project_path:
        pathProject = project_path + "/" + project
    pathProject += "/"
    if not os.path.isdir(pathProject):
        raise ValueError("Project not found")
    if not os.path.exists(pathProject + file):
        raise ValueError("File not found")
    return pathProject, project



# -*- coding: utf-8 -*-
"""
    tqwgp-parser
    ~~~~~~~~~~~~~~~~~~~~~
    TQWGP parser package.

    :copyright: (c) 2021 Yoan Tournade.
"""
import hy
# # Expose main parsing functions.
from .parser import parse_quote, parse_invoices



import sys
import re
import ast
from setuptools import setup

readme_markdown = None
with open("README.md") as f:
    readme_markdown = f.read()

setup(
    name="tqwgp-parser",
    version="0.0.3",
    url="https://github.com/YtoTech/talk-quote-work-getpaid-parser",
    license="AGPL-3.0",
    author="Yoan Tournade",
    author_email="y@yoantournade.com",
    description="A library for parsing Talk Quote Work Get-Paid (TQWGP) text-based compliant sales and accounting documents.",
    long_description=readme_markdown,
    long_description_content_type="text/markdown",
    packages=["tqwgp_parser"],
    include_package_data=True,
    package_data={
        "tqwgp_parser": ["*.hy"],
    },
    zip_safe=False,
    platforms="any",
    install_requires=["hy"],
)
